@@ -1,8 +1,11 @@
 createReach.default <-
-function(name="Unttitled",routingMethod="muskingum",inflow=NA,routingParams=list(k=3,x=0.2,bedWith=NULL,sideSlope=2,channelSlope=NULL,manningRoughness=0.025,riverLength=NULL),delayInflow=1,label,downstream=NA)
+function(name="Unttitled",routingMethod="muskingum",inflow=NA,routingParams=list(k=3,x=0.2,bedWith=NULL,sideSlope=2,channelSlope=NULL,manningRoughness=0.025,riverLength=NULL),delayInflow=1,downstream=NA)
 {
-   if(missing(routingParams)){stop("routingParams is not specified!")}
-   if(missing(label)){stop("label code is not specified!")}
+   if(!any(class(downstream)==c('createJunction','createDiversion','createReservoir','createSubbasin','createReach')))
+   {
+      if(!is.na(downstream)) stop('Bad object specified as downstream!')
+   }
+   if(any(class(downstream)==c('createJunction','createDiversion','createReservoir','createSubbasin','createReach'))) downstream<-downstream$operation$label
    if(routingMethod=="muskingum")
    {
       if(is.null(routingParams$k) && is.null(routingParams$x)){stop("One of the following is not specified: x, k")}
@@ -13,10 +16,9 @@ function(name="Unttitled",routingMethod="muskingum",inflow=NA,routingParams=list
    }
 
    result<-list()
-   operation<-createReach.base(name,routingMethod,inflow,routingParams,delayInflow,label,downstream)
+   operation<-createReach.base(name,routingMethod,inflow,routingParams,delayInflow,downstream)
    result$operation<-operation
    result$call<-match.call()
    class(result)<-"createReach"
    return(result)
-
-}
+}
\ No newline at end of file
